############################################################################
# Matt Rodriguez, LBNL
#Copyright (c) 2003, The Regents of the University of California,
#through Lawrence Berkeley National Laboratory
#(subject to receipt of any required approvals from the U.S. Dept. of Energy).
#All rights reserved.
############################################################################
import os, sys
from ConfigParser import ConfigParser
try:
    import ez_setup
    ez_setup.use_setuptools()
    from setuptools.core import setup, Extension
except:
    from distutils.core import setup, Extension

"""
distutils script to build pyGsi
"""
def _version():
    cf = ConfigParser()
    cf.read('setup.cfg')
    major = cf.getint('version', 'major')
    minor = cf.getint('version', 'minor')
    patchlevel = cf.getint('version', 'patchlevel')
    candidate = cf.getint('version', 'candidate')

    version = "%d.%d.%d" % (major, minor, patchlevel)
    if candidate:
        version += '_rc%d' % candidate

    text = ('# Auto-generated file; do not edit\n'
            'Version = (%d, %d, %d)\n' % (major, minor, patchlevel))

    vmod = 'pyGsi/version.py'
    if not os.path.exists(vmod) or open(vmod, 'r').read() != text:
        open(vmod, 'w').write(text)

    return version


def parse_args(option_dict):
    """
    Find the openssl prefix of the openssl installation
    that has the libraries that we want to link against.
    """
    args = sys.argv[1:]
    for arg in args:
        if arg.find("--openssl") == 0:
            option_dict['openssl_prefix'] = arg.split("=")[1]
            sys.argv.remove(arg)
            
option_dict = {'openssl_prefix': '/usr'} 
parse_args(option_dict)
include_dirs = [os.path.join(option_dict['openssl_prefix'], "include")]
library_dirs = [os.path.join(option_dict['openssl_prefix'], "lib")]
libraries = ['ssl', 'crypto']

mic = Extension(name = 'pyGsi.__mic',
                sources = ["src/mic_wrap.c"],
                include_dirs = include_dirs,
                library_dirs = library_dirs,
                libraries = libraries)

proxy_scripts = [os.path.join("scripts", "proxy_init"),
                 os.path.join("scripts", "proxy_info"),
                 os.path.join("scripts", "proxy_destroy")]
                

setup(name="pyGsi", version=_version(),
      py_modules=["pyGsi.proxylib", 
          "pyGsi._mic",
          "pyGsi.test.test_ProxyFactory"],
      scripts=proxy_scripts, author="Matt Rodriguez", 
      author_email="MKRodriguez@lbl.gov", ext_modules = [mic],
      url="http://dsd.lbl.gov/gtg/projects/pyGridWare/pyGsi.html")

